#
# spec file for package gnome-disk-utility
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-disk-utility
Version:        46.1
Release:        2.1
Summary:        Disks application for dealing with storage devices
License:        GPL-2.0-or-later
Group:          Hardware/Other
URL:            https://wiki.gnome.org/Apps/Disks
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(dvdread) >= 4.2.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.31.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.16.0
BuildRequires:  pkgconfig(libcanberra-gtk3) >= 0.1
BuildRequires:  pkgconfig(libhandy-1) >= 1.5.0
BuildRequires:  pkgconfig(liblzma) >= 5.0.5
BuildRequires:  pkgconfig(libnotify) >= 0.7
BuildRequires:  pkgconfig(libsecret-1) >= 0.7
BuildRequires:  pkgconfig(libsystemd) >= 209
BuildRequires:  pkgconfig(pwquality) >= 1.0.0
BuildRequires:  pkgconfig(udisks2) >= 2.7.6
Requires:       udisks2
Recommends:     f2fs-tools
Recommends:     udftools
Recommends:     (exfatprogs or exfat-utils)

%description
The gnome-disk-utility project provides the Disks application for
dealing with storage devices.

%lang_package

%prep
%autosetup -p1

%build
%meson \
%if !0%{?sle_version}
	--sysconfdir=%{_distconfdir} \
%endif
	-Dlogind=libsystemd \
	-Dgsd_plugin=true \
	-Dman=true \
	%{nil}
%meson_build

%install
%meson_install

%find_lang %{name} %{?no_lang_C}

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.gnome.DiskUtility.appdata.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop

%files
%license COPYING
%doc AUTHORS HACKING NEWS README.md TODO
%{_bindir}/gnome-disks
%{_bindir}/gnome-disk-image-mounter
%{_datadir}/applications/*.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Disks.gschema.xml
%{_datadir}/icons/hicolor/
%{_mandir}/man1/gnome-disk-image-mounter.1%{?ext_man}
%{_mandir}/man1/gnome-disks.1%{?ext_man}
%{_datadir}/metainfo/org.gnome.DiskUtility.appdata.xml
%{_datadir}/dbus-1/services/org.gnome.DiskUtility.service
# The session / settings daemon plugin:
%{_libexecdir}/gsd-disk-utility-notify
%if !0%{?sle_version}
%{_distconfdir}/xdg/autostart/org.gnome.SettingsDaemon.DiskUtilityNotify.desktop
%else
%{_sysconfdir}/xdg/autostart/org.gnome.SettingsDaemon.DiskUtilityNotify.desktop
%endif

%files lang -f %{name}.lang

%changelog
* Thu Mar 20 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Add (exfatprogs or exfat-utils), f2fs-tools and udftools
  Recommends: Support formatting disks to exFAT, F2FS and UDF.
* Tue Sep  3 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.1:
  + metainfo:
  - fix URLs
  - replace screenshots
  + Updated translations.
* Wed Mar 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + metainfo: Fix wrong developer id
  + Updated translations.
* Wed Mar 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + appdata: Improve appdata for AppStream 1.0.
* Tue Mar 12 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Move install commands into %%install section
* Fri Dec  1 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 45.1:
  + creatediskimage: Fix crash if image creation has errors.
  + Update appdata
  + Updted translations.
* Sun Sep 10 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 45.0:
  + benchmark-dialog: Silence two maybe-uninitialized warnings.
  + Updated translations.
* Mon Aug 14 2023 Yifan Jiang <yfjiang@suse.com>
- Support build environments like SLE 15 SP5 and Leap 15.5 which
  had %%{_distconfdir) not defined yet.
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + flatpak:
  - Use popt default branch
  - popt switched to cmake
  + Updated translations.
* Fri Mar  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + flatpak: People like to rename branches back and forth.
  + Add .dir-locals.
  + various: Remove GNU Emacs file variables.
  + Updated translations.
- Add appstream-glib BuildRequires and a check section, where we
  validate appstream data and desktop file during build.
* Thu Feb 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Update POTFILES.in.
  + Updated translations.
* Fri Jan 27 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.alpha:
  + change-passphrase-dialog: Port to GtkBuilder templates
  + ci: Use OCI images hosted on Quay
  + createotherpage: Re-factor
  + crypttab-dialog: Port to GtkBuilder templates
  + estimator:
  - Don't override finalize()
  - Port to use G_DECLARE_FINAL_TYPE
  + filesystemdialog: Port to use GtkBuilder Templates
  + flatpak: Use new default branch name for popt
  + format-disk-dialog: Port to GtkBuilder templates
  + help-overlay: Remove visible properties
  + new-disk-image-dialog: Port to GtkBuilder templates
  + partition-dialog: Port to GtkBuilder templates
  + passwordstrength:
  - Don't override setter
  - Port to use G_DECLARE_FINAL_TYPE
  + unlock-dialog: Port to GtkBuilder templates
  + Updated translations.
- Pass sysconfdir=%%{_distconfdir} to meson and move
  org.gnome.SettingsDaemon.DiskUtilityNotify.desktop autostart file
  to /usr/etc/ subdirs.
* Fri Sep 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated translations.
* Sat Sep  3 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 43.rc:
  + flatpak: Use devel branch for Udisks.
  + flatpak: Use libfdisk from util-linux.
  + flatpak: Use devel build for blockdev.
  + Updated translations.
* Mon Aug  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + ci: Use nigthly image
  + flatpak:
  - Use specific udisk tag
  - own org.gnome.Disks.NotificationMonitor
  - Use fallback-x11 instead of x11
  - Add libnotify
  + desktop: Mark app as using notifications
  + Updated translations.
* Fri Jul 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + flatpak: use alternative location for keyutils-1.6.1.tar.bz2.
  + Remove incompatible volatile qualifiers.
  + INSTALL: Fix broken link.
  + Add development pointers to the readme and remove obsolete
    TODOs.
  + gduatasmartdialog: Replace deprecated GIO function.
  + gduformatdiskdialog: Fix parameter of g_signal_connect () and
    remove unused variable.
  + gduapplication: Fix parameter of g_signal_connect ().
  + gduutils:
  - Implement gdu_utils_can_format.
  - Remove unused variable in gdu_utils_can_check.
  + createfilesystempage:
  - Check for vfat support.
  - Add tooltip for missing utilities.
  + gduapplication: Free string after use.
  + gduatasmartdialog: Free string after use.
  + gduwindow: Free GList after use.
  + meson: Use gnome.post_install.
  + Updated translations.
- Add desktop-file-utils BuildRequires: New dependency.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Add release helper.
  + Updated translations.
* Sat Mar  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + Update screenshots.
  + Updated translations.
* Fri Feb 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Restore old window destruction to fix data retrieval
  + Updated translations.
* Tue Feb  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.alpha:
  + Support dark theme preference (required to bump libhandy to
    1.5.0).
  + Rewrite GUI parts to avoid deprecated things and prepare for
    GTK 4.
  + Improve the visual appearance of the devtab toolbar.
  + metainfo: Align app name with .desktop name.
  + Updated translations.
- Drop update-desktop-files BuildRequires and macro, not needed.
- Pass man=true to meson, ensure we build man pages.
- Drop 60.patch: Fixed upstream.
* Tue Feb  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 60.patch: Fix build with meson 0.61 and newer.
* Thu Nov  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Replace option libsystemd=true with new logind=libsystemd,
  following upstream changes.
* Sat Sep 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + metainfo: Add minimum screen size requirement and input
    recommendations
  + desktop-file: Add X-Purism-Form-Factor.
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Fri Sep  3 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.rc:
  + Updated translations.
* Mon Aug 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.beta:
  + gducreateformatdialog: Use LUKS2 for new encrypted partitions.
  + volume-menu/gduwindow: Add button and dialog to take filesystem
    ownership.
  + ui: Change the icon of the detach loop device button.
  + shortcuts: Add keyboard shortcut for the application menu.
  + gduwindow: Make menus toggleable.
  + ui: Change the icon of the job cancel button.
  + ui: Align job section.
  + ui: Enable ellipsis on the job remaining label.
  + gdubenchmarkdialog: Save benchmark settings.
  + Flatpak build fixes.
  + Updated translations.
* Fri Aug  6 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.alpha:
  + UI: Highlight destructive actions.
  + Updated translations.
* Sun Jul 11 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.2:
  + gdusdmonitor: Fix notification icon.
  + Escape hyperlink text in mount point label.
* Sun May  2 2021 Michael Gorse <mgorse@suse.com>
- Update to version 40.1:
  + restore: do not wipe disk after error if it's a dismissed auth
    error.
  + Make SMART attributes view expand vertically.
  + Updated translations.
* Fri Mar 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Updated translations.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.beta:
  + ui:
  - Make disks-devtab a scrolledwindow.
  - Move margins from stack to devtab.
  - Use HdyStatusPage for empty view.
  - Replace GtkTable with GtkGrid.
  - Replace Notebook with stack in the main window.
  - Replace GtkHBox and GtkVBox.
  - Adjust margins.
  + build:
  - build: Pin libhandy wrapper to a specific version.
  - Bump required libhandy to version 1.1.90.
* Fri Feb 12 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + window:
  - Make adaptive with HdyLeaflet.
  - Add empty state
  + Add libhandy as a subproject (allowing to build if not
    available as system library).
  + Do not display zram devices.
  + Flatpak build fixes.
- Add pkgconfig(libhandy-1) BuildRequires: new dependency.
* Thu Feb 11 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.2:
  + Ignore the --xid option when formatting from Nautilus (this
    aligns the behavior under X11 with that on Wayland).
  + Updated translations.
* Mon Dec 14 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.1:
  + Do not display zram devices.
  + Updated translations.
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Build/install readme improvements (INSTALL).
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.2:
  + Fix creating partitions by using special parameter when
    requesting the maximal partition size.
  + Always show other filesystem format choices.
  + Fix unmounting drives by waiting until UDisks updates the
    unmounted filesystem.
  + Updated translations.
* Mon Jul 20 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.3:
  + Fix creating partitions by using special parameter when
    requesting the maximal partition size.
  + Updated translations.
* Sat Mar 21 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Wait until UDisks updates the unmounted filesystem.
  + Updated translations.
* Sat Mar 21 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Updated translations.
* Sat Mar 21 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91:
  + Add a shortcut for Keyboard Shorcuts page.
  + Updated translations.
* Sat Mar 21 2020 dimstar@opensuse.org
- Update to version 3.35.2:
  + Create a nightly app icon.
  + Segfault: unlock dialog: Add a mnemonic to the keyfiles label.
  + Updated translations.
* Sat Mar 21 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.5:
  + Wait until UDisks updates the unmounted filesystem.
* Sun Feb 16 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.4:
  + Updated translations.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Flatpak: Remove unnecessary udev module.
  + Convert README to markdown.
  + Updated translations.
- README -> README.md in %%doc.
* Tue Sep  3 2019 mgorse@suse.com
- Update to version 3.33.92:
  + Build documentation for Flatpak.
  + Flatpak manifest fixes.
  + Updated translations.
* Sun Sep  1 2019 mgorse@suse.com
- Update to version 3.33.91:
  + Updated translations.
  + Changes in version 3.33.90:
  + Labels for toolbar items added for accessibility.
  + Mark missing string for translation.
  + Updated translations.
  + Changes in version 3.33.4:
  + build: Various meson updates (many commits).
  + build: Add flatpak manifest.
  + ci: Add basic CI support.
  + ci: Add support for flatpak building.
  + README/INSTALL update and info for Flatpak usage for development
  + Updated translations.
  + Changes in version 3.33.3:
  + build: Define logind as combo option of 'libsystemd',
    'libelogind', 'none'.
  + Don't require filesystem label when formatting.
  + build: remove autodetection of features and require a recent
    UDisks.
  + build: add elogind support for seat retrieval.
  + Rephrase English confirmation message.
  + Updated translations.
- Up udisks dependency.
- Require meson >= 0.50.0.
* Tue Apr  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Updated translations.
* Sun Mar 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Updated translations.
* Mon Feb 18 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + build: stop checking for fallocate.
  + icon: app icon adjustments.
  + Update the UI to match current guidelines.
  + Update POTFILES.in.
  + Added total-lbas-written and total-lbas-read to translatable
    strings.
  + unlock dialog: Add tooltip for keyfile chooser button.
  + Updated translations.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.2:
  + Update app icon.
* Wed Oct 24 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Updated translations.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + GduVolumeGrid: Use starred icon instead of user-bookmarks.
  + Remove redundant error showing.
  + Updated translations.
* Sat Sep  8 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
- Remove lang package from recommended packages as it already
  supplements main package (same effect, it's redundant).
* Tue Aug 28 2018 bjorn.lie@gmail.com
- Update to version 3.29.92:
  + Mark missing string for translation.
  + Updated translations.
- Use autosetup macro, pass libsystemd=true and gsd_plugin=true to
  meson, ensure we build the features we want (currently in sync
  with upstream defaults).
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + mtvoid: Fix swapped "Number of Samples" tooltips in benchmark
    dialog.
  + Updated translations.
* Mon Jul 23 2018 dimstar@opensuse.org
- Help translation-update-upstream finding the right gettext domain
  name: pass "po %%{name}" to the call.
* Sat Jun 23 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + segfault: Add TrueCrypt/VeraCrypt support.
  + Register inhibitor for benchmark thread.
  + Update URLs after migration.
  + Updated translations.
* Thu May 31 2018 bjorn.lie@gmail.com
- Update to version 3.28.3:
  + Query NTFS tooling from UDisks (> 2.7.2). Disks queried for
    mkntfs in the $PATH directly which does not work for
    non-sudoers without /sbin.
* Tue May  8 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Register inhibitor for benchmark thread (no string change).
  + Updated translations.
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Format dialog: Fix NULL deref when no partition table is
    present.
  + Updated translations.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Feb 22 2018 dimstar@opensuse.org
- Update to version 3.27.91:
  + Fix tooltip for “Hide from Firmware” GPT partition flag.
  + Drop redundant “Legacy BIOS Bootable” text in tooltip.
  + Updated translations.
* Tue Feb 20 2018 luc14n0@linuxmail.org
- Update to version 3.27.90:
  + Hide devices if mounted with x-gdu.hide.
  + Restore: don't attempt to open target read-only.
  + Updated translations.
- Replace + in GPL License tag to '-or-later' complying with SPDX
  3.0.
* Thu Dec 21 2017 luc14n0@linuxmail.org
- Update to version 3.27.3:
  + Set partition type for MBR partitions.
  + Updated translations.
* Tue Nov 14 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Resize dialog: missing mnemonic activations.
  + No format option for extended partitions.
  + Updated translations.
* Thu Nov  2 2017 badshah400@gmail.com
- Update to version 3.27.1:
  + Redesign Format Dialog.
  + Spruce up typography in new translatable strings.
  + Updated translations.
* Wed Nov  1 2017 badshah400@gmail.com
- Update to version 3.26.2:
  + No format option for extended partitions.
  + Updated translations.
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Fix license link in logo SVG metadata.
  + Fix SIGSEGV in gdu_utils_get_all_contained_objects.
  + Keep FS mounted while growing partition.
  + Show mount options for swap volumes.
  + Updated translations.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
- Run spec-cleaner, modernize spec file.
* Mon Sep  4 2017 zaitor@opensuse.org
- Update to version 3.25.92:
  + Updated translations.
* Mon Aug 21 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Fix translation headers.
  + Tweak memory management in filesystem dialog.
  + Add unmount function to edit filesystem dialog.
  + Correct tooltip texts in resize dialog.
  + Correct text for partition size entry.
  + Disable action buttons during jobs.
  + Delay sensitivity during job updates.
  + Updated translations.
* Tue Aug 15 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Update POTFILES.in.
  + Unmark placeholder strings from translation.
  + Fix appdata file name.
  + Add a more detailed description for the project.
  + Detect UDisks version 2.7.2.
  + Move partition size helpers.
  + Move volume and partition utility functions.
  + Resize and repair helper functions.
  + Resize, Check and Repair Dialogs.
  + Updated translations.
* Mon Jul 17 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Enable Large File Support for Disks.
  + Update Window for Power State Changes.
  + Update AppData Information.
  + build:
  - Created template file for service file.
  - Port to meson build system.
  - Remove autotools.
  + Updated translations.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream port to Meson build system.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Drop glib2_gsettings_schema_post(un), desktop_database_post(un)
  and icon_theme_cache_post(un) from post(un), no longer needed as
  we have filetriggers support in rpm to take care of this for us.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Use MIME types for disk images.
  + Prompt to stop jobs when closing.
  + update doap file with new maintainer.
  + Clarify meaning of encryption/mounting options.
  + Disable auto-clear before operations needing unmount.
  + Implicit auto-clear handling for unmount and lock buttons.
  + Use correct callback finish method.
  + Insensitive auto-clear switch for unused loop device.
  + Remove unused erase disks dialog.
  + Fix unmounting and probing of mounted volumes.
  + Change label dialog hint.
  + Restrict maximal label length if known.
  + Hints for passphrase fields.
  + Remove deprecated GTK functions.
  + Fix wrong behavior of filesystem creation dialog.
  + The UUID of the selected volume is shown.
  + Add app menu entry to create an empty disk image.
  + Add tooltip text to Auto-clear switch.
  + Update po/Makevars/POTFILES.in.
  + Updated translations.
* Sat May  6 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Fix unmounting and probing of mounted volumes.
  + Fix wrong behavior of filesystem creation dialog.
  + Updated translations.
* Mon Mar 20 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Fix crash in error path.
  + Updated translations.
* Sat Mar 11 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Fix broken desktop files.
  + Drop unused gsettings schema.
  + Updated translations.
* Fri Jan 13 2017 zaitor@opensuse.org
- Update to version 3.23.4:
  + Fix failure in g-s-d plugin.
  + Updated translations.
- Add pkgconfig(libsystemd) BuildRequires: Build with systemd
  support.
* Tue Dec 13 2016 dimstar@opensuse.org
- Update to version 3.23.3:
  + Update gnome-settings-daemon plugin for 3.23.
  + Code cleanups.
  + Stop using intltool for translations.
  + Use more Unicode in translatable strings.
  + Updated translations.
- Drop pkgconfig(gnome-settings-daemon) and intltool BuildRequires:
  no longer needed.
* Fri Nov 11 2016 dimstar@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Fix layout with GTK+ 3.22.
  + Updated translations.
* Tue Jun 21 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Fix gear menu location when running in Wayland.
  + Fix app menu icon when running outside GNOME.
  + Updated translations.
* Tue May 17 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Sat May  7 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Fix window menu placement under Wayland.
  + Updated translations.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop 0001-Be-more-careful-with-XIDs.patch and
  0002-Make-dialog-work-with-xid-again.patch: fixed upstream.
* Fri Apr  8 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Sun Dec 13 2015 zaitor@opensuse.org
- Update to version 3.19.3:
  + Add names for option arguments in --help output.
  + Updated translations.
* Fri Nov 27 2015 zaitor@opensuse.org
- Update to version 3.18.3.1:
  + Fix the --restore-disk-image option.
* Fri Nov  6 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Updated translations.
* Sun Oct 11 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Add X-GNOME-Utilities category to desktop file.
  + Updated translations.
* Tue Oct  6 2015 zaitor@opensuse.org
- Own %%dir %%{_datadir}/appdata for openSUSE Leap 42.1.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Fix incorrect assertions that were recently added.
  + Updated translations.
* Sun Aug 30 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Add missing tooltips.
  + Accessibility improvements.
  + Adjust halign of partition menu.
  + Fix line wrap in info bars.
  + Code cleanups.
  + Updated translations.
* Fri Jun 26 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Improve integration with Unity desktop environment.
  + Fix Indic font rendering in benchmark dialog.
  + Fix AppData file name to match the new .desktop file basename.
  + Updated translations.
* Mon May 25 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Don't show name example when creating logical partition.
  + Refine appearance of volume grid.
  + Make D-Bus activatable.
  + Convert to new-style commandline option handling.
  + Remove deprecated encoding key from desktop file.
  + Simplify translation of gsettings schemas.
  + Fix format string signedness warnings.
  + Add appdata file.
  + Mention -h option in manpage.
  + Fix build with --disable-gsd-plugin.
  + Updated translations.
* Sun May 24 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix benchmarking disks on 32-bit architectures.
  + Updated translations.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Provide symbolic app icon.
  + Don't show name example when creating logical partition.
  + Fix overly-wide benchmark dialog.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Make SMART dialog resizable (bgo#723469).
  + Disambiguate menu items to reduce confusion (bgo#742652).
  + Fix halign of hamburger menu.
  + Fix a typo in a translatable string.
  + Updated translations.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Fix theming in the volume grid (bgo#723495).
  + Fix headerbar item positions (bgo#729349).
  + Use new icon for the gear menu (bgo#732980).
  + Updated translations.
* Sun Sep 21 2014 dimstar@opensuse.org
- Add %%glib2_gsettings_schema_post/postun handling to scriptlets.
* Fri Sep 19 2014 fcrozat@suse.com
- Ensure schemas are properly registered at install
  time(bnc#897530).
* Thu Apr 24 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + GduVolumeGrid: Fix theming problem.
* Tue Apr  1 2014 mgorse@suse.com
- Add 0001-Be-more-careful-with-XIDs.patch and
  0002-Make-dialog-work-with-xid-again.patch: fix formatting from
  Nautilus (bgo#721278). From upstream gnome-3-10 branch.
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + GduDVDSupport:
  - Nuke overlapping ranges.
  - Update comments and add some more debug.
  + GduVolumeGrid: Cap minimum width to 300 pixels.
  + Drop unneeded margin inside image buttons.
  + Updated translations.
* Fri Feb 14 2014 dimstar@opensuse.org
- Update to version 3.11.0:
  + Use GtkHeaderBar and CSD.
  + Remove MD-RAID support.
  + Use flat list in device tree.
  + Use media icon, if available.
  + Include UI files in application binary via gresource(1).
  + Update "Edit GPT Partition" dialog.
  + Only show "Power Off" menu item if the drive can power off.
  + Fix warning in "Restore Disk Image" dialog.
  + Be more careful with XIDs.
  + Make dialog work with --xid again.
  + app menu: standardize Help/About/Quit.
  + Capitalize title of the restore image file chooser.
  + General: Fix deprecation warnings.
  + Updated translations.
* Sun Sep 29 2013 zaitor@opensuse.org
- Update to version 3.10.0:
  + Lower liblzma dep to latest stable (5.0.5) instead of dev
    (5.1.0).
  + Set NoDisplay=true for Disk Image writer and Disk Image Mounter
    apps.
  + Fix autogen and configure.
  + Updated translations.
- Remove V=1 from make as it only fills up the obs buildlog to no
  use, debugging is done locally anyway.
* Wed Aug 21 2013 dimstar@opensuse.org
- Update to version 3.9.0:
  + Use new udisks 2.1.1 API (if available) to show better
    partition descriptions.
  + utils: make unfuse_path() replace $HOME with ~.
  + Disks: Add new --restore-disk-image option.
  + Don't use two lines in device selection combobox.
  + Use fallocate(2) rather than posix_fallocate(3).
  + Use right size when calculating error-percentage when creating
    disk image.
  + Don't unmount CD/DVD discs before creating a disk image of
    them.
  + Verify that the file passed to --restore-disk-image is a
    regular file.
  + Add support for restoring XZ compressed disk images.
  + Remove application/x-raw-disk-image{,-xz-compressed} MIME
    types.
  + Fix default folder for disk images.
  + Type problems prevent compilation with GCC 4.8 on i686.
  + Bugs fixed: bgo#695346.
  + Updated translations.
- Add pkgconfig(liblzma) BuildRequires: new dependency.
- Drop gdu-fix-build-gcc-4_8.patch: fixed upstream.
- Lower the upstream specified dependency on liblzma from
  5.1.0(alpha) to version 5.0(stable branch) (bgo#706471).
* Fri Jul 19 2013 zaitor@opensuse.org
- Add gdu-fix-build-gcc-4_8.patch, fix build with gcc 4.8.
* Wed May 29 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + GduWindow: fix ensure_unused() method to pass the right object
    in callbacks.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Bump dependency of udisks to 2.1.0 (stable release).
  + Updated translations.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Add a --format-device command line option.
  + Add a --xid command line option for the format dialog
  + Resolve backing crypto device when selecting object.
  + utils: move code to ensure unused volume to gduutils.c
  + Add HighContrast icons.
  + GduVolumeGrid: properly reset flags.
  + Convey free space for mounted volumes.
  + Updated translations.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + Reword ATA SMART failure notification
  + Show notification when RAID array is degraded
  + Also show spinner in device tree if a MD-RAID scrub is in
    progress
  + Convey data rate and remaning time for MD-RAID sync operations
  + Improve checking whether a sync op is underway
  + Make it possible to start/stop data scrubbing operations from
    the drive menu
  + Avoid hiding widgets only to show them again
  + Add a "Power Off" icon for drives that can be powered off
  + Update keywords for Disks application
  + Alert the user by playing a sound the first time a read error
    happens
  + Show warning dialog if read errors occured during disk image
    creation
  + Reword text in the dialog shown if read errors happened during
    image creation
- Changes from version 3.7.0:
  + Initial MD-RAID support
  + Show array size and unify some formatting routines
  + Show "N required (M detected)" if not all RAID members are
    available
  + Update SMART dialog
  + Bugs fixed: bgo#683772
  + Updated translations.
- Add new BuildRequires:
  + pkgconfig(libcanberra-gtk3): needed for audible warnings.
  + pkgconfig(dvdread): for the new DVD image support.
  + pkgconfig(gnome-settings-daemon): New generic dependency.
  + pkgconfig(libnotify): needed for notifications.
* Sat Oct  6 2012 zaitor@opensuse.org
- Update to version 3.6.1:
  + Add window title to Create Partition dialog.
  + Don't show application launcher for Disk Image Mounter.
  + Updated translations.
* Fri Sep 21 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Relicense from LGPLv2+ to GPLv2+
  + If creating an image from iso9660/udf, suggest Disc_Label.iso
    as the filename
  + Remember the last-used directory for disk images
  + Also update disk image directory when attaching disk images
  + Don't force file types when selecting a folder
  + Make Create/Restore Disk Image dialogs non-modal
  + Try opening the device file directly when creating images of
    CD/DVD discs
  + Factor out common code and put it in a static library
  + Use libgdu in gnome-disk-image-mounter
  + Don't default to NTFS unless the mkntfs(8) command exists
  + Remove css bits for now
  + Store directory of last image file chosen, not the full path
  + Use set_current_folder_uri(), not set_current_folder()
  + Fix problems with overlapping partitions in disk images
  + Handle gtk_file_chooser_get_current_folder_uri() returning NULL
  + Add window title to various dialogs.
- Add pkgconfig(gmodule-2.0) BuildRequires: new checked dependency.
- Drop gnome-disk-utility-overflow.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh: We
  don't carry any patches anymore.
* Fri Jul 27 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + about-dialog: use gnome-disks for the icon, not palimpsest
  + Add a settings dialog for power management and acoustic levels
  + Add a "Wake-up from Standby" menu item
  + Add back Benchmark dialog
  + Add erase option when formatting, show job progress and allow
    job cancelation
  + Add support for ATA secure erase and non-cancelable jobs
  + disk-image-mounter: leave mounting to gnome-shell
  + Don't allow standby on SSD drives
  + Don't show sub-minute precision for restoring/creating disk
    images
  + Don't show WWN if we already show a serial
  + Handle partition setups with overlapping partitions
  + Make volume grid look right (grey, not blue) when selected and
    unfocused
  + Port from libgnome-keyring-1 to libsecret-1
  + Refine handling of overlapping partitions
  + Rescan device when we're done restoring a disk image onto it
  + Show "Create Disk Image" even if free space on a drive is
    selected
  + Show estimated time remaining when a job is pending
  + Show sample size and number of samples for benchmarks
  + Show vendor recommended AAM level and use it as a default
  + Use GtkLevelBar widget for conveying passphrase strength.
- Replace pkgconfig(gnome-keyring-1) with pkgconfig(libsecret-1),
  following upstreams switch to libsecret.
- Add gnome-disk-utility-overflow.patch: fix bufferoverflow.
- Add gnome-common BuildRequires and call to gnome-autogen.sh:
  Needed as above patch touches the build system.
* Thu Jun  7 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Disks: SMART dialog improvements
  + GduPasswordStrenghWidget: use libpwquality
  + Updated translations.
- Add pkgconfig(pwquality) BuildRequires: new dependency.
- Add pkgconfig(gnome-keyring-1) BuildRequires: configure checks
  for it.
- Add docbook-xsl-stylesheets and xsltproc BuildRequires.
* Thu May 10 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Fix build with older udisk version
  + If drive is on another seat, show "Connected to another seat"
  + Check keyring for LUKS passphrase and put it in passphrase
    entry if available
  + Add a "Auto-clear" switch for loop devices
  + Add "Disk Image Mounter" utility and associate with
    application/x-cd-image
  + Updated translations.
* Mon Apr 23 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Initialize gettext support so i18n actually works.
  + Small theming fix.
  + Updated translations.
* Tue Mar 13 2012 vuntz@opensuse.org
- Update to version 3.3.93:
  + Use "Size", not "Disk Size"
  + Show WWN for a disk/drive, if available
  + Fix a couple of internationalization problems
  + Reword potentially confusing description of SMART attribute
  + Various interface improvements to fstab and crypttab dialogs
  + Updated translations.
* Mon Feb 27 2012 vuntz@opensuse.org
- Update to version 3.3.92:
  + Improve fstab and crypttab dialogs.
  + Use units in application provided CSS to shut up recent GTK+
    warning
  + Fix bug when updating negative checkbutton options
  + Use proper capitalization for "Edit mount options..." menu item
  + Updated translations.
* Wed Feb  8 2012 vuntz@opensuse.org
- Update to version 3.3.91:
  + Add application menu.
  + Include "nosuid,nodev" when proposing options for a new fstab
    entry.
  + Add nofail checkbox when editing entries.
  + Several other code changes.
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Sat Jan 21 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Complete rewrite, using udisks2.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Completely change packaging because of the complete rewrite:
  + Add pkgconfig() BuildRequires: gio-unix-2.0, udisks2.
  + Drop pkgconfig() BuildRequires: avahi-ui-gtk3, dbus-glib-1,
    glib-2.0, gnome-keyring-1, libatasmart, libnautilus-extension,
    libnotify, udisks, unique-3.0, x11.
  + Add intltool BuildRequires.
  + Drop gdbm-devel, gnome-doc-utils-devel, gtk-doc BuildRequires.
  + Drop libgdu0, libgdu-gtk0, libgdu-devel, libgdu-gtk-devel
    subpackages: the libraries don't exist anymore.
  + Rename libgdu-lang subpackage to gnome-disk-utility-lang.
  + Change udisks Requires to udisks2, since this what is used now.
  + Add gnome-disk-utility-lang Recommends.
  + Stop passing now non-existing --disable-scrollkeeper option to
    configure.
  + Rewrite summary and description.
* Wed Oct 26 2011 badshah400@gmail.com
- Modified categories in .desktop file so that it is grouped with
  "System" applications in the desktop menus (bnc#714333)
* Sat Jul  9 2011 dimstar@opensuse.org
- Update to version 3.0.2:
  + Revert back to using HBox and VBox
  + Change build system to not avoid deprecated functions.
- Changes from version 3.0.1:
  + bgo#612872: wrong base-10 prefix KB (correct is kB)
  + Add support for DeviceAutomountHint
  + Add --enable-strict and default to this for developer builds
  + Add Unity to OnlyShowIn
  + Replacing hbox/vbox with box
  + Updated translations.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Use the right directory for the nautilus extension
  + Drop fix-nautilus-extension-path.patch: fixed upstream.
  + Add Settings category to palimpsest.desktop, via call to
  %%suse_update_desktop_file.
* Tue Mar 29 2011 fcrozat@novell.com
- Update to version 2.91.7:
  + bgo#645174: New icons
  + Use more accurate categories in the desktop file
  + Make the S.M.A.R.T and benchmark dialogs work better with the
    shell.
  + Updated translations.
- Add fix-nautilus-extension-path.patch: ensure the right version
  is used for nautilus extension path.
* Thu Mar  3 2011 fcrozat@novell.com
- Update to version 2.91.6:
  + Port to GTK+ 3.
  + Use non-NULL display for launch context
  + Updated translations.
- Change BuildRequires to pkgconfig() ones:
  + old ones: dbus-1-glib-devel, glib2-devel, libatasmart-devel,
    libgnome-keyring-devel, libnotify-devel, libunique-devel,
    nautilus-devel, udisks-devel.
  + pkgconfig() ones: avahi-ui-gtk3, dbus-glib-1, glib-2.0,
    gnome-keyring-1, gtk+-3.0, libatasmart, libnautilus-extension,
    libnotify, udisks, unique-3.0, x11.
- Remove explicit Requires of devel packages in devel subpackages:
  they will automatically be added the pkgconfig() way.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Fri Dec 17 2010 vuntz@opensuse.org
- Update to version 2.32.1:
  + Require libnotify 0.6.1
* Tue Sep 28 2010 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Wed Sep 15 2010 dimstar@opensuse.org
- Update to version 2.32.0:
  + Compile against latest gtk+.
  + Make the Apply button in edit-name dialogs default.
  + Use accessor functions instead direct access.
  + Nuke gtk-doc usage for now.
  + Updated translations.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.30.1:
  + bgo#613004 - Crash in gdu_adapter_get_object_path at
    gdu-adapter.c:288
  + rh#560336 - Rendering broken for some part of application
- Changes from version 2.30.0:
  + Fix typo when figuring out if remote access is enabled
  + Handle loop devices
  + Rudimentary support for loop files
  + Don't include non-working Help menu item
  + bgo#606663 - Change default chunk size to match mdadm (512KiB)
  + Use gtk_widget_has_focus() instead of deprecated
    GTK_WIDGET_HAS_FOCUS()
  + Unify mix color handling
  + Fix theming for the volume grid widget respect
  + String-related fixes.
  + Add StartupNotify=true to the desktop file
* Tue Mar 23 2010 dimstar@opensuse.org
- Remove en@shaw locale on openSUSE <= 11.2.
* Wed Feb 24 2010 dimstar@opensuse.org
- Update to version 2.29.90:
  + A new UI
  + For a full list of changes please see NEWS.
- Change dependencies from DeviceKit-disks to udisks.
- BuildRequires gdbm-devel and libavahi-glib-devel.
* Wed Dec 23 2009 vuntz@opensuse.org
- Change gnome-keyring-devel BuildRequires to
  libgnome-keyring-devel, following the module split upstream.
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 2.28.1:
  + Turn some warnings that are not fatal into debug messages
  + Use stock delete and apply buttons
  + Fix library translations
  + Use translated string for button label
  + Translate file system types
  + Forgotten string
  + Nautilus extension: ref and unref objects correctly
  + Don't crash when presentable has no device
  + Updated translations.
* Fri Oct  2 2009 vuntz@opensuse.org
- Update to version 2.28.0:
  + Improved UI for ATA SMART dialogs
  + Fix string issues (bgo#592006, bgo#593381)
  + Updated translations.
- Add libatasmart-devel BuildRequires.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 0.5:
  + Fix strings for translation.
  + bgo#591170 – fix smartmoontools URL
  + Add support for new :drive-can-spindown property
  + Start writing a dialog to set up Software RAID
  + More detail in the TreeView and incremental work on the Create
    RAID dialog
  + First usable version of the Create RAID Array dialog
  + Fix a crasher when determining unallocated on unactivated
    drives
  + Fix up drive name for non-USB SD drives
  + grid: Clarify property comment
  + Add API for new :device-presentation-nopolicy property in DKD
  + Use g_mount_unmount_with_operation() in the format tool
  + Drop polkit references from pc files
  + Updated translations.
- Remove PolicyKit-devel and PolicyKit-gnome-devel Requires from
  devel packages.
* Sat Jul 25 2009 captain.magnus@opensuse.org
- Update to version 0.4:
  + Rip out PolicyKit support and bump version after release
  + Check for DeviceKit-disks pkg-config file so the build can fail
    earlier
  + Add support for new DriveDetach() method and :drive-can-detach
    property
  + Expose a way to detach devices
  + Catch up with latest DeviceKit-disks API where
    :drive-requires-eject is gone
  + fdo#584962 - palimpsest SIGTRAPs on unknown flag
  + fdo#581179 - Don't expose branding to the user
  + fdo#582881 - Typos in original strings
  + fdo#585332 - Wrong spelling "The mininum size of the element"
    in original
  + fdo#585384 - "Blank" - adjective or verb
  + fdo#585388 - Translation comment needed "Operations should go
    here"
  + fdo#585392 - Spelling error "incomptible"
  + fdo#581841 - String typos
  + Use themed icons for Zip and Jaz drives
  + Rework formatting tool so it's simpler and easier to use
  + Use new API to add UI for checking/repairing Linux MD RAID
    arrays
  + Use GtkInfoBar to show job progress
  + Port from SexyUrlLabel to GtkLabel
  + Fix a bug where GduLinuxMdDrive didn't emit ::job-changed
    signals
  + Remove gdu-section-job.[ch] from POTFILES.in since they no
    longer exist
  + Use AM_SILENT_RULES if available
  + Don't show markup in the UI
  + Translation updates.
- Remove PolicyKit-devel, PolicyKit-gnome-devel, libsexy-devel and
  libxml2-devel from BuildRequires.
* Sat Jun 13 2009 mboman@suse.de
- New packages
